@@ -7,6 +7,7 @@ use std::marker::PhantomData;
 use std::pin::Pin;
 use std::sync::Arc;
 use std::time::Duration;
+use std::fmt;
 
 use async_channel::bounded;
 use async_channel::Receiver;
@@ -14,6 +15,7 @@ use async_channel::Sender;
 use async_lock::Mutex;
 use bytes::BytesMut;
 use event_listener::Event;
+use fluvio_future::net::ConnectionFd;
 use futures_util::stream::{Stream, StreamExt};
 use pin_project::{pin_project, pinned_drop};
 use tokio::select;
@@ -60,6 +62,12 @@ pub struct MultiplexerSocket {
     terminate: Arc<Event>,
 }
 
+impl fmt::Debug for MultiplexerSocket {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "MultiplexerSocket {}", self.sink.id())
+    }
+}
+
 impl Drop for MultiplexerSocket {
     fn drop(&mut self) {
         // notify dispatcher
@@ -74,7 +82,11 @@ impl MultiplexerSocket {
 
     /// create new multiplexer socket, this always starts with correlation id of 1
     /// correlation id of 0 means shared
+    #[allow(clippy::clone_on_copy)]
     pub fn new(socket: FluvioSocket) -> Self {
+        let id = socket.id().clone();
+        debug!(socket = %id, "spawning dispatcher");
+
         let (sink, stream) = socket.split();
 
         let multiplexer = Self {
@@ -85,6 +97,7 @@ impl MultiplexerSocket {
         };
 
         MultiPlexingResponseDispatcher::run(
+            id,
             stream,
             multiplexer.senders.clone(),
             multiplexer.terminate.clone(),
@@ -100,7 +113,7 @@ impl MultiplexerSocket {
     }
 
     /// create socket to perform request and response
-    #[instrument(skip(self, req_msg))]
+    #[instrument(skip(req_msg))]
     pub async fn send_and_receive<R>(
         &self,
         mut req_msg: RequestMessage<R>,
@@ -123,25 +136,29 @@ impl MultiplexerSocket {
 
         req_msg.header.set_correlation_id(correlation_id);
 
-        debug!(
-            "serial multiplexing: sending request: {} id: {}",
-            R::API_KEY,
-            correlation_id
-        );
-        self.sink.send_request(&req_msg).await?;
-
+        trace!(correlation_id, "senders trying lock");
         let mut senders = self.senders.lock().await;
         senders.insert(correlation_id, SharedSender::Serial(bytes_lock.clone()));
         drop(senders);
 
         let (msg, msg_event) = bytes_lock;
+        // make sure we set up listener, otherwise dispatcher may notify before
+        let listener = msg_event.listen();
+
+        debug!(api = R::API_KEY, correlation_id, "sending request");
+        self.sink.send_request(&req_msg).await?;
+        trace!(correlation_id, "waiting");
 
         select! {
+
             _ = sleep(Duration::from_secs(*MAX_WAIT_TIME)) => {
+
+                trace!("serial socket for: {}  timeout happen, id: {}", R::API_KEY, correlation_id);
+                // clean channel
                 let mut senders = self.senders.lock().await;
                 senders.remove(&correlation_id);
                 drop(senders);
-                debug!("serial socket for: {}  timeout happen, id: {}", R::API_KEY, correlation_id);
+
 
                 Err(IoError::new(
                     ErrorKind::TimedOut,
@@ -149,8 +166,10 @@ impl MultiplexerSocket {
                 ).into())
             },
 
-            _ = msg_event.listen() => {
+            _ = listener => {
 
+                // clean channel
+                trace!(correlation_id,"msg event");
                 let mut senders = self.senders.lock().await;
                 senders.remove(&correlation_id);
                 drop(senders);
@@ -160,7 +179,7 @@ impl MultiplexerSocket {
 
                         if let Some(response_bytes) =  &*guard {
 
-                            debug!("receive serial socket id: {}, bytes: {}", correlation_id, response_bytes.len());
+                            debug!(correlation_id, len = response_bytes.len(),"receive serial message");
                             let response = R::Response::decode_from(
                                 &mut Cursor::new(&response_bytes),
                                 req_msg.header.api_version(),
@@ -186,7 +205,7 @@ impl MultiplexerSocket {
     }
 
     /// create stream response
-    #[instrument(skip(self, req_msg, queue_len))]
+    #[instrument(skip(self,req_msg), fields(api = R::API_KEY))]
     pub async fn create_stream<R>(
         &self,
         mut req_msg: RequestMessage<R>,
@@ -196,28 +215,34 @@ impl MultiplexerSocket {
         R: Request,
     {
         let correlation_id = self.next_correlation_id().await;
+
         req_msg.header.set_correlation_id(correlation_id);
 
-        debug!(
-            "send request: {} correlation_id: {}",
-            R::API_KEY,
-            correlation_id
-        );
-        self.sink.send_request(&req_msg).await?;
+        trace!(correlation_id,request = ?req_msg, "new correlation id");
 
-        // it is possible that msg have received by dispatcher before channel is inserted into senders
-        // but it is easier to clean up
+        // set up new channel
         let (sender, receiver) = bounded(queue_len);
         let mut senders = self.senders.lock().await;
 
         // remove any closed channel, this is not optimal but should do trick for now
+
         senders.retain(|_, shared_sender| match shared_sender {
             SharedSender::Serial(_) => true,
             SharedSender::Queue(sender) => !sender.is_closed(),
         });
+
         senders.insert(correlation_id, SharedSender::Queue(sender));
         drop(senders);
 
+        trace!(correlation_id, "created new channel");
+
+        self.sink.send_request(&req_msg).await?;
+
+        trace!(correlation_id, "request send");
+
+        // it is possible that msg have received by dispatcher before channel is inserted into senders
+        // but it is easier to clean up
+
         Ok(AsyncResponse {
             receiver,
             header: req_msg.header,
@@ -294,25 +319,36 @@ impl<R: Request> Stream for AsyncResponse<R> {
 
 /// This decodes fluvio protocol based streams and multiplex into different slots
 struct MultiPlexingResponseDispatcher {
+    id: ConnectionFd,
     senders: Senders,
     terminate: Arc<Event>,
 }
 
+impl fmt::Debug for MultiPlexingResponseDispatcher {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "MultiplexDisp({})", self.id)
+    }
+}
+
 impl MultiPlexingResponseDispatcher {
-    pub fn run(stream: FluvioStream, senders: Senders, terminate: Arc<Event>) {
+    pub fn run(id: ConnectionFd, stream: FluvioStream, senders: Senders, terminate: Arc<Event>) {
         use fluvio_future::task::spawn;
 
-        let dispatcher = Self { senders, terminate };
+        let dispatcher = Self {
+            id,
+            senders,
+            terminate,
+        };
 
-        debug!("dispatcher: spawning dispatcher loop");
         spawn(dispatcher.dispatcher_loop(stream));
     }
 
+    #[instrument(skip(stream))]
     async fn dispatcher_loop(mut self, mut stream: FluvioStream) {
         let frame_stream = stream.get_mut_tcp_stream();
 
         loop {
-            trace!("dispatcher: waiting for next response from stream ");
+            trace!("waiting");
 
             select! {
                 frame = frame_stream.next() => {
@@ -321,7 +357,7 @@ impl MultiPlexingResponseDispatcher {
                             let mut correlation_id: i32 = 0;
                             match correlation_id.decode(&mut msg, 0) {
                                 Ok(_) => {
-                                    trace!(correlation_id,"decoded correlation");
+                                    trace!(correlation_id,len = msg.len(), "received frame");
 
                                     if let Err(err) = self.send(correlation_id, msg).await {
                                         error!("error sending to socket, {}", err)
@@ -330,11 +366,11 @@ impl MultiPlexingResponseDispatcher {
                                 Err(err) => error!("error decoding response, {}", err),
                             }
                         } else {
-                            debug!("dispatcher: problem getting frame from stream. terminating");
+                            debug!("problem getting frame from stream. terminating");
                             break;
                         }
                     } else {
-                        debug!("dispatcher: inner stream has terminated ");
+                        debug!("inner stream has terminated ");
 
                         let guard = self.senders.lock().await;
                         for sender in guard.values() {
@@ -371,19 +407,21 @@ impl MultiPlexingResponseDispatcher {
     }
 
     /// send message to correct receiver
-    #[instrument(skip(self, msg))]
-    pub async fn send(&mut self, correlation_id: i32, msg: BytesMut) -> Result<(), SocketError> {
+    #[instrument(skip(self, msg),fields( msg = msg.len()))]
+    async fn send(&mut self, correlation_id: i32, msg: BytesMut) -> Result<(), SocketError> {
         let mut senders = self.senders.lock().await;
         if let Some(sender) = senders.get_mut(&correlation_id) {
             match sender {
                 SharedSender::Serial(serial_sender) => {
+                    trace!("found serial");
                     // this should always succeed since nobody should lock
                     match serial_sender.0.try_lock() {
                         Some(mut guard) => {
                             *guard = Some(msg);
-                            trace!("send back msg with correlation: {}", correlation_id);
                             drop(guard); // unlock
                             serial_sender.1.notify(1);
+                            trace!("found serial");
+
                             Ok(())
                         }
                         None => Err(IoError::new(
@@ -397,6 +435,7 @@ impl MultiPlexingResponseDispatcher {
                     }
                 }
                 SharedSender::Queue(queue_sender) => {
+                    trace!("found stream");
                     queue_sender.send(Some(msg)).await.map_err(|err| {
                         IoError::new(
                             ErrorKind::BrokenPipe,
